@@ -128,6 +128,19 @@ MainWindow::MainWindow(
       "WARNING: The N900 Flash LEDs are very bright -- avoid looking directly at them!",
       0);
   }
+
+  if (settings.contains("UseIndicatorLEDAsTorch"))
+  {
+    bool uilat = settings.value("UseIndicatorLEDAsTorch").toBool();
+
+    ui->redButton->setChecked(uilat);
+
+    useIndicatorLED(uilat);
+  }
+  else
+  {
+    ui->redButton->setChecked(false);
+  }
 }
 
 
@@ -139,6 +152,8 @@ MainWindow::~MainWindow()
     settings.setValue("BrightLightWarningSeen", true);
   }
 
+  settings.setValue("UseIndicatorLEDAsTorch", ui->redButton->isEnabled());
+
   if (aboutForm) delete aboutForm;
   if (strobeForm) delete strobeForm;
   if (morseForm) delete morseForm;
@@ -323,10 +338,15 @@ void MainWindow::setUseCameraButton(
 void MainWindow::useIndicatorLED(
   bool useILED)
 {
+  if (useIndicatorLEDAsTorch != useILED)
+  {
+    led->swapLEDs();
+  }
+
   useIndicatorLEDAsTorch = useILED;
 
   // Turn off the torch in either case:
-  turnTorchOff();
+//  turnTorchOff();
 }
 
 
@@ -465,6 +485,18 @@ void MainWindow::on_actionStrobe_Flash_triggered()
 }
 
 
+void MainWindow::on_whiteButton_clicked()
+{
+  useIndicatorLED(false);
+}
+
+
+void MainWindow::on_redButton_clicked()
+{
+  useIndicatorLED(true);
+}
+
+
 void MainWindow::on_torchButton_clicked()
 {
   // Skip this method if we are in Morse Key mode:
